<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hant">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>關於 </translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐贈</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>聯繫</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>許可證： </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>螢幕截圖和註釋工具</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>擷取</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>包含游標</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>延遲</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>擷取模式</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>在釘選視窗中顯示圖片</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>圖片複製到剪貼簿</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>上傳圖片</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>打開圖片父目錄</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>儲存圖片</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>隱藏主視窗</translation>
    </message>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>操作設置</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>操作</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>需要浮水印圖片</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>請通過「選項」&gt;「設置」&gt;「註釋器」&gt;「更新」新增浮水印圖片</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>平滑繪製的路徑</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>如啟用，繪製完成後
消除筆和標記路徑。</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>平滑因子</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>增加平滑因子將減少
筆和記號筆的精度，但會
使它們更平滑。</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>註釋器設置</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>記住註釋器選擇並在啟動時載入</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>繪製後切換到選擇工具</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>數字工具種子更改將更新所有數字項目</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>禁用此選項將導致數字工具的更改
種子僅影響新項目，而不影響現有項目。
禁用此選項將允許重複的數字。</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>畫布顏色</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>註釋區域畫布的預設背景顏色
改變顏色只會影響新的註釋區域。</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>繪圖後選擇項目</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>啟用此選項後，將在創建項目後對其進行選擇，
從而可以更改設置。</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>使用預設模式在啟動時擷取螢幕截圖</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>應用程式樣式</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>設置定義GUI外觀的應用程式樣式。
更改要求ksnip重新啟動才能生效。</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>應用程式設置</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>自動將新的擷取複製到剪貼簿</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>使用標籤</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>修改需要重啟後生效。</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>以單程序模式運行 ksnip</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>當只有一個標籤時隱藏標籤欄。</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>啟用這個選項將會只允許一個ksnip程序運行，
所有其它程序啟動時會將參數傳給第一個程序
然後退出。改變這個選項需要在關閉所有程序
後啟動新的程序。</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>在移動時記住主視窗的位置並在啟動時載入</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>自動隱藏標籤</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>自動隱藏 Docks</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>在啟動時隱藏工具欄和註釋器，
可以按下 Tab 鍵顯示 Dock。</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>自動調整內容大小</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>自動調整主視窗的大小以適合內容圖片。</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>啟用除錯</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>啟用寫入控製台的除錯輸出。
更改需要 ksnip 重新啟動才能生效。</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>根據內容大小是允許視窗管理器接收新內容的延遲。
如果未正確調整主視窗以適應新內容，
增加延遲可能會改善行為。</translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">瀏覽</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>貢獻者：</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>西班牙語翻譯</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>荷蘭語翻譯</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>俄語翻譯</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>挪威語的翻譯</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>法語翻譯</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>波蘭語翻譯</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap 和 Flatpak 支持</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>作者：</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>警告 - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>擷取 %1%2%3 已經被修改。
是否需要儲存？</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>用游標繪製一個矩形區域</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>擷取全螢幕，包括所有螢幕</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>擷取游標所在的螢幕</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>擷取目前焦點所在的視窗</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>擷取當前在滑鼠游標下的內容</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>擷取上一次選擇的矩形區域的螢幕截圖</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>使用 the screenshot Portal 截圖</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>社區</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>錯誤報告</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>如果您有一般問題、想法或只想談談 ksnip，&lt;br/&gt;請加入我們的 %1 或我們的 %2 伺服器。</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>請使用 %1 報告故障。</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>複製到剪貼簿失敗</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>以 base64 圖片編碼形式複製到剪貼簿失敗。</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>已複製到剪貼簿</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>已將圖片的 base64 編碼複製到剪貼簿。</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>刪除圖片</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>項目 &apos;%1&apos; 將被刪除。
你想繼續嗎？</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>歡迎捐款</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>捐贈</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip 是一個非盈利的 Copyleft 自由軟體項目，並且&lt;br/&gt;仍有一些費用需要支付，&lt;br/&gt;如域名成本或跨平台支持的硬體成本。</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>&lt;br/&gt;如果你想通過請開發者喝啤酒或咖啡提供幫助或只是想讚賞所做的工作，歡迎看看%1這裡%2。</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>成為 GitHub 贊助者？</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>也可以在 %1此處%2 捐款。</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>通過點擊「新增」標籤按鈕來新增新的操作。</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>矩形區域</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>上一個矩形區域</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>全螢幕（所有螢幕）</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>當前螢幕</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>活動的視窗</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>游標下的視窗</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>截圖入口</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>強制匿名上傳。</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用戶名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP 上傳器</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>上傳成功</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>無法為上傳儲存臨時圖片。</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>無法啟動程序，請檢查路徑和權限是否正確。</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>程序已崩潰</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>程序超時。</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>程序讀錯誤。</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>程序寫錯誤。</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>網路錯誤，請檢查控製台輸出。</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>上傳失敗</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>腳本在標準錯誤上有輸出。</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP 上傳成功完成。</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>未知錯誤。</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>連接錯誤。</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>權限錯誤。</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>腳本 %1 上傳成功。</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>已上傳至 %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>啟用全域熱鍵</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>擷取矩形區域</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>擷取全螢幕</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>擷取當前螢幕</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>擷取活動的視窗</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>擷取游標下的視窗</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>全域熱鍵</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>擷取上一次的矩形區域</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>使用 Portal 擷取</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>當前僅 Windows 和 X11 支持熱鍵。
禁用此選項也會使僅 ksnip 操作快捷方式。</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>截圖時包含滑鼠游標</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>螢幕截圖時游標
游標是否可見。</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>圖片採集器</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>使用 XDG-DESKTOP-PORTAL 的通用 Wayland 實現
以不同的方式處理螢幕縮放。
啟用此選項將確定當前螢幕縮放
並將其
應用於 ksnip 中的螢幕截圖 。</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME 和 KDE Plasma 支持各自的Wayland，
也有通用的 XDG-DESKTOP-PORTAL 螢幕截圖。
啟用該選項將強制 KDE Plasma 和 GNOME
使用 XDG-DESKTOP-PORTAL 截圖方式。
改變這個選項需要重新啟動 ksnip。</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>擷取螢幕截圖後顯示主視窗</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>截圖時隱藏主視窗</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>擷取一個新截圖時隱藏主視窗。</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>隱藏或最小化主視窗時在擷取新的
螢幕快照後顯示主視窗。</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>強制 Generic Wayland (xdg-desktop-portal) 截圖</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>縮放 Generic Wayland (xdg-desktop-portal) 截圖</translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur 歷史記錄</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>時間戳</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>連結</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>刪除連結</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>上傳到 imgur.com 完成！</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>收到新記號，正在嘗試再次上傳…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur 記號已過期，正在請求新記號…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>強制匿名上傳</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>總是將 Imgur 連結複製到剪貼簿</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>客戶端密碼</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>輸入Imgur Pin，它將會被替換為記號。</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>獲得 PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>獲得記號</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur 歷史記錄</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur上傳程式</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用戶名</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>等待 imgur.com 的回應…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com 記號已成功更新。</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com 記號更新錯誤。</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>上傳到Imgur後在預設瀏覽器中打開</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>直接連結到圖片</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>基址 URL：</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>基本 URL 用來與 Imgur 通信。
更改需要重啟應用。</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>清空記號</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>無法打開圖片</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>無法從路徑 %1 中打開圖片</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>觸發並擷取螢幕截圖
的延遲秒數。</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>秒</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>將螢幕截圖儲存到檔案</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>複製螢幕截圖到剪貼簿</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>剪裁</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>剪裁螢幕截圖</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>未儲存</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>打開印表機設置對話框</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>列印預覽</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>打開「列印預覽」對話框，可以在其中更改圖片方向</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>選項(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>幫助(&amp;H)</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>新增浮水印</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>為擷取的圖片新增浮水印。可以新增多個浮水印。</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>無法顯示圖片</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>另存為...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>嵌入貼上</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>釘選</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>將截圖固定在無邊框的前台視窗上</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>需要提供一個圖片。</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>複製路徑</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打開目錄</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>顯示 Docks</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>隱藏 Docks</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>複製為數據 URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>打開 &amp; 最近</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>修改畫布</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>上傳 triggerCapture 到外部來源</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>複製 triggerCapture 到系統剪貼簿</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>縮放圖片</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>旋轉</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>旋轉圖片</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>操作</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>圖片檔案</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>另存為</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打開目錄</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>複製路徑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>擷取</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>關閉其它</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>關閉所有</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">預設</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">瀏覽</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">名稱</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">版本</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>圖片已重命名</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>圖片重命名失敗</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>重命名圖片</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>新檔案名：</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>成功將圖片重命名為 %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>未能將圖片重命名為 %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>另存為</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>圖片已儲存</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>儲存圖片失敗</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>圖片檔案</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>已儲存至 %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>未能將圖片儲存至 %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>自動將新的擷取儲存到預設位置</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>在放棄未儲存的更改之前提示儲存</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>記住上次儲存的目錄</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>啟用後每次儲存都會將設置中的儲存目錄
覆蓋為上次的儲存目錄。</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>擷取儲存位置和檔案名</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>支持 JPG、PNG 和 BMP 格式。如果沒有提供格式，將使用PNG作為預設格式。
檔案名可以包含以下通配符。
- $Y, $M, $D 代表日期，$h, $m, $s 代表時間，或 $T 代表 hhmmss 格式的時間。
- 多個連續的 # 代表計數器。若 #### 代表 0001，下一次擷取則會是0002。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>儲存設置</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>擷取儲存位置</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>因子</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>儲存品質</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>指定 0 可以獲得小的壓縮檔案，100 會獲得大的未壓縮檔案。
並非所有圖片格式都像 JPEG 一樣支持全部範圍。</translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>將腳本輸出複製到剪貼簿</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>腳本：</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>上傳時調用的腳本的路徑。在上傳過程中，腳本將被以
臨時 png 檔案的路徑作為單一參數調用。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>上傳腳本</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>選擇上傳腳本</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>在上傳腳本輸出至標準錯誤時停止</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>當腳本輸出至標準錯誤時，將上傳標記為失敗。
沒有此設置，腳本中的錯誤將不會被註意到。</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>過濾器：</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>正規表示法。僅在匹配上正規表示法時複製到剪貼簿。
若省略此項，將複製所有內容。</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>圖片採集器</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur 上傳程式</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>註釋器</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>上傳程式</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>上傳腳本</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>貼紙</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>截圖區域</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>托盤圖示</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>浮水印</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>操作</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP 上傳器</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>使用控製柄調整所選矩形的大小，或通過拖動選區來移動它。</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>使用方向鍵移動選中區域。</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>按 CTRL 鍵的同時使用方向鍵移動左上角的控製柄。</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>按 ALT 鍵的同時使用方向鍵移動右下角的控製柄。</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>可以通過設置禁用此消息。</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>點擊並拖動選擇一個矩形區域或按 ESC 鍵退出。</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>選擇後按住 CTRL 鍵調整選區大小。</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>選擇後，按住 CTRL 鍵防止調整大小。</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>如果未進行選擇，則60秒後將取消操作。</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>可以通過設置禁用此消息。</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>截圖時凍結圖片</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>啟用後將在選擇矩形區域時凍結背景。
它還會更改延遲螢幕截圖的行為，
從而更改了延遲螢幕截圖的行為，
啟用此選項將延遲發生在顯示剪裁區域之前，
而禁用此選項
將延遲發生在顯示剪裁區域之後。
Wayland 始終禁用此功能，
MacOs 始終啟用此功能。</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>在截圖區域顯示放大鏡</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>顯示放大背景圖的
放大鏡。此設置僅在
啟用了&apos;在截圖時凍結圖片&apos;時生效。</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>在截圖區域顯示標尺</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>在截圖區域，顯示從螢幕邊緣到游標
的水平線和垂直線。</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>顯示截圖區域的位置和尺寸訊息</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>當未按下游標左鍵時，
顯示位置，
當按下游標按鈕時，
所選區域的大小顯示在擷取區域的左上方。</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>預設情況下允許調整矩形區域的大小</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>啟用後，
將在選擇矩形區域後允許調整選擇的大小。
完成調整大小後，
可以按Enter鍵確認選擇。</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>顯示截圖區域訊息文字</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>截圖區域的游標顏色</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>設置剪切區域游標的顏色。</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>截圖區域的游標粗細</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>設置剪切區域游標的粗細。</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>截圖區域</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>截圖區域裝飾色</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>設置剪切區域上
所有裝飾元素的顏色。</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>截圖區域透明度</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>剪裁區域中未選擇區域的 Alpha。
數字越小越透明。</translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>向下</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>使用預設貼紙</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>貼紙設置</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>向量圖片檔案 (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>新增貼紙</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>顯示編輯器</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>使用托盤圖示</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>啟用後，如系統視窗管理器支持，會向任務欄新增托盤圖示。
更改需要重新啟動才能生效。</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>最小化到托盤</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>啟動時最小化到托盤</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>關閉到托盤</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>顯示編輯器</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>擷取</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>預設托盤圖示行為</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>左鍵單擊托盤圖示時的預設觸發行為。</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>托盤圖示設置</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>使用平台特定的通知服務</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>啟用後將使用嘗試使用特定於平台的通知存在時提供服務。
 更改需要重新啟動才能生效。</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>顯示托盤圖示通知</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>選擇圖片</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>圖片檔案</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>需要上傳腳本</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>請通過選項&gt;設置&gt;上傳腳本新增一個上傳腳本</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>擷取上傳</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>您即將把圖片上傳至外部站點。您是否想要繼續？</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>上傳前請求確認</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>上傳類型：</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation type="unfinished">Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>腳本</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>上傳程式</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>構建版本</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>使用：</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>浮水印圖片</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>旋轉浮水印</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>啟用後，將新增旋轉 45° 的浮水印</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>浮水印設置</translation>
    </message>
</context>
</TS>
